@@ -1,6 +1,6 @@
 // Copyright Kevlin Henney, 2000-2005.
 // Copyright Alexander Nasonov, 2006-2010.
-// Copyright Antony Polukhin, 2011-2023.
+// Copyright Antony Polukhin, 2011-2024.
 //
 // Distributed under the Boost Software License, Version 1.0. (See
 // accompanying file LICENSE_1_0.txt or copy at
@@ -35,8 +35,6 @@
 #include <b/type_traits/conditional.hpp>
 #include <b/type_traits/is_integral.hpp>
 #include <b/type_traits/is_float.hpp>
-#include <b/type_traits/has_left_shift.hpp>
-#include <b/type_traits/has_right_shift.hpp>
 #include <b/detail/lcast_precision.hpp>
 
 #include <b/lexical_cast/detail/widest_char.hpp>
@@ -44,6 +42,10 @@
 
 #include <array>
 
+#ifndef BOOST_NO_CXX17_HDR_STRING_VIEW
+#include <string_view>
+#endif
+
 #include <b/lexical_cast/detail/buffer_view.hpp>
 #include <b/container/container_fwd.hpp>
 
@@ -57,6 +59,9 @@ namespace boost {
     template<class IteratorT>
     class iterator_range;
 
+    // Forward declaration of boost::basic_string_view from Utility
+    template<class Ch, class Tr> class basic_string_view;
+
     namespace detail // normalize_single_byte_char<Char>
     {
         // Converts signed/unsigned char to char
@@ -174,6 +179,19 @@ namespace boost {
         > {};
 #endif
 
+#ifndef BOOST_NO_CXX17_HDR_STRING_VIEW
+        template < class Char, class Traits >
+        struct stream_char_common< std::basic_string_view< Char, Traits > >
+        {
+            typedef Char type;
+        };
+#endif
+        template < class Char, class Traits >
+        struct stream_char_common< boost::basic_string_view< Char, Traits > >
+        {
+            typedef Char type;
+        };
+
 #ifdef BOOST_HAS_INT128
         template <> struct stream_char_common< boost::int128_type >: public boost::type_identity< char > {};
         template <> struct stream_char_common< boost::uint128_type >: public boost::type_identity< char > {};
@@ -191,7 +209,7 @@ namespace boost {
     namespace detail // deduce_source_char_impl<T>
     {
         // If type T is `deduce_character_type_later` type, then tries to deduce
-        // character type using boost::has_left_shift<T> metafunction.
+        // character type using streaming metafunctions.
         // Otherwise supplied type T is a character type, that must be normalized
         // using normalize_single_byte_char<Char>.
         // Executed at Stage 2  (See deduce_source_char<T> and deduce_target_char<T>)
@@ -204,20 +222,29 @@ namespace boost {
         template < class T >
         struct deduce_source_char_impl< deduce_character_type_later< T > >
         {
-            typedef boost::has_left_shift< std::basic_ostream< char >, T > result_t;
+            template <class U>
+            static auto left_shift_type(long)
+                -> decltype( std::declval<std::basic_ostream< char >&>() << std::declval<const U&>(), char{});
 
-#if defined(BOOST_LCAST_NO_WCHAR_T)
-            static_assert(result_t::value,
-                "Source type is not std::ostream`able and std::wostream`s are not supported by your STL implementation");
-            typedef char type;
-#else
-            typedef typename boost::conditional<
-                result_t::value, char, wchar_t
-            >::type type;
-
-            static_assert(result_t::value || boost::has_left_shift< std::basic_ostream< type >, T >::value,
-                "Source type is neither std::ostream`able nor std::wostream`able");
+#if !defined(BOOST_LCAST_NO_WCHAR_T)
+            template <class U>
+            static auto left_shift_type(int)
+                -> decltype( std::declval<std::basic_ostream< wchar_t >&>() << std::declval<const U&>(), wchar_t{});
 #endif
+
+            template <class U>
+            static void left_shift_type(...);
+
+            using type = decltype(left_shift_type<T>(1L));
+
+            static_assert(!std::is_same<type, void>::value,
+#if defined(BOOST_LCAST_NO_WCHAR_T)
+                "Source type is not std::ostream`able and std::wostream`s are "
+                "not supported by your STL implementation"
+#else
+                "Source type is neither std::ostream`able nor std::wostream`able"
+#endif
+            );
         };
     }
 
@@ -237,20 +264,29 @@ namespace boost {
         template < class T >
         struct deduce_target_char_impl< deduce_character_type_later<T> >
         {
-            typedef boost::has_right_shift<std::basic_istream<char>, T > result_t;
+            template <class U>
+            static auto right_shift_type(long)
+                -> decltype( std::declval<std::basic_istream< char >&>() >> std::declval<U&>(), char{});
 
-#if defined(BOOST_LCAST_NO_WCHAR_T)
-            static_assert(result_t::value,
-                "Target type is not std::istream`able and std::wistream`s are not supported by your STL implementation");
-            typedef char type;
-#else
-            typedef typename boost::conditional<
-                result_t::value, char, wchar_t
-            >::type type;
-
-            static_assert(result_t::value || boost::has_right_shift<std::basic_istream<wchar_t>, T >::value,
-                "Target type is neither std::istream`able nor std::wistream`able");
+#if !defined(BOOST_LCAST_NO_WCHAR_T)
+            template <class U>
+            static auto right_shift_type(int)
+                -> decltype( std::declval<std::basic_istream< wchar_t >&>() >> std::declval<U&>(), wchar_t{});
 #endif
+
+            template <class U>
+            static void right_shift_type(...);
+
+            using type = decltype(right_shift_type<T>(1L));
+
+            static_assert(!std::is_same<type, void>::value,
+#if defined(BOOST_LCAST_NO_WCHAR_T)
+               "Target type is not std::istream`able and std::wistream`s are "
+               "not supported by your STL implementation"
+#else
+               "Target type is neither std::istream`able nor std::wistream`able"
+#endif
+            );
         };
     }
 
@@ -275,44 +311,14 @@ namespace boost {
         struct deduce_target_char
         {
             typedef typename stream_char_common< T >::type stage1_type;
-            typedef typename deduce_target_char_impl< stage1_type >::type stage2_type;
-
-            typedef stage2_type type;
+            typedef typename deduce_target_char_impl< stage1_type >::type type;
         };
 
         template < class T >
         struct deduce_source_char
         {
             typedef typename stream_char_common< T >::type stage1_type;
-            typedef typename deduce_source_char_impl< stage1_type >::type stage2_type;
-
-            typedef stage2_type type;
-        };
-    }
-
-    namespace detail // extract_char_traits template
-    {
-        // We are attempting to get char_traits<> from T
-        // template parameter. Otherwise we'll be using std::char_traits<Char>
-        template < class Char, class T >
-        struct extract_char_traits
-                : boost::false_type
-        {
-            typedef std::char_traits< Char > trait_t;
-        };
-
-        template < class Char, class Traits, class Alloc >
-        struct extract_char_traits< Char, std::basic_string< Char, Traits, Alloc > >
-            : boost::true_type
-        {
-            typedef Traits trait_t;
-        };
-
-        template < class Char, class Traits, class Alloc>
-        struct extract_char_traits< Char, boost::container::basic_string< Char, Traits, Alloc > >
-            : boost::true_type
-        {
-            typedef Traits trait_t;
+            typedef typename deduce_source_char_impl< stage1_type >::type type;
         };
     }
 
@@ -360,16 +366,11 @@ namespace boost {
                     Source, typename boost::enable_if<boost::is_integral<Source> >::type
                 >
         {
-#ifndef BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS
             BOOST_STATIC_CONSTANT(std::size_t, value =
                   std::numeric_limits<Source>::is_signed +
                   std::numeric_limits<Source>::is_specialized + /* == 1 */
                   std::numeric_limits<Source>::digits10 * 2
               );
-#else
-            BOOST_STATIC_CONSTANT(std::size_t, value = 156);
-            static_assert(sizeof(Source) * CHAR_BIT <= 256, "");
-#endif
         };
 
         // Helper for floating point types.
@@ -387,8 +388,6 @@ namespace boost {
                 Source, typename boost::enable_if<boost::is_float<Source> >::type
             >
         {
-
-#ifndef BOOST_LCAST_NO_COMPILE_TIME_PRECISION
             static_assert(
                     std::numeric_limits<Source>::max_exponent10 <=  999999L &&
                     std::numeric_limits<Source>::min_exponent10 >= -999999L
@@ -397,9 +396,6 @@ namespace boost {
             BOOST_STATIC_CONSTANT(std::size_t, value =
                     5 + lcast_precision<Source>::value + 6
                 );
-#else // #ifndef BOOST_LCAST_NO_COMPILE_TIME_PRECISION
-            BOOST_STATIC_CONSTANT(std::size_t, value = 156);
-#endif // #ifndef BOOST_LCAST_NO_COMPILE_TIME_PRECISION
         };
     }
 
@@ -429,33 +425,7 @@ namespace boost {
                 "Your compiler does not have full support for char32_t" );
 #endif
 
-            typedef typename boost::conditional<
-                boost::detail::extract_char_traits<char_type, Target>::value,
-                typename boost::detail::extract_char_traits<char_type, Target>,
-                typename boost::detail::extract_char_traits<char_type, no_cv_src>
-            >::type::trait_t traits;
-
-            typedef boost::integral_constant<
-              bool,
-              boost::is_same<char, src_char_t>::value &&                                 // source is not a wide character based type
-                (sizeof(char) != sizeof(target_char_t)) &&  // target type is based on wide character
-                (!(boost::detail::is_character<no_cv_src>::value))
-                > is_string_widening_required_t;
-
-            typedef boost::integral_constant<
-              bool,
-                !(boost::is_integral<no_cv_src>::value ||
-                  boost::detail::is_character<
-                    typename deduce_src_char_metafunc::stage1_type          // if we did not get character type at stage1
-                  >::value                                                           // then we have no optimization for that type
-                 )
-                > is_source_input_not_optimized_t;
-
-            // If we have an optimized conversion for
-            // Source, we do not need to construct stringbuf.
-            BOOST_STATIC_CONSTANT(bool, requires_stringbuf =
-                (is_string_widening_required_t::value || is_source_input_not_optimized_t::value)
-            );
+            typedef std::char_traits<char_type> traits;
 
             typedef boost::detail::lcast_src_length<no_cv_src> len_t;
         };
@@ -468,29 +438,33 @@ namespace boost {
         {
             typedef lexical_cast_stream_traits<Source, Target>  stream_trait;
 
-            typedef detail::lexical_istream_limited_src<
+            typedef detail::lcast::optimized_src_stream<
                 typename stream_trait::char_type,
                 typename stream_trait::traits,
-                stream_trait::requires_stringbuf,
                 stream_trait::len_t::value + 1
-            > i_interpreter_type;
+            > optimized_src_stream;
+            
+            template <class T>
+            static auto detect_type(int)
+                -> decltype(std::declval<optimized_src_stream&>().stream_in(std::declval<lcast::exact<T>>()), optimized_src_stream{});
 
-            typedef detail::lexical_ostream_limited_src<
+            template <class T>
+            static lcast::ios_src_stream<typename stream_trait::char_type, typename stream_trait::traits> detect_type(...);
+
+            using from_src_stream = decltype(detect_type<Source>(1));
+
+            typedef detail::lcast::to_target_stream<
                 typename stream_trait::char_type,
                 typename stream_trait::traits
-            > o_interpreter_type;
+            > to_target_stream;
 
             static inline bool try_convert(const Source& arg, Target& result) {
-                i_interpreter_type i_interpreter;
-
-                // Disabling ADL, by directly specifying operators.
-                if (!(i_interpreter.operator <<(arg)))
+                from_src_stream src_stream;
+                if (!src_stream.stream_in(lcast::exact<Source>{arg}))
                     return false;
 
-                o_interpreter_type out(i_interpreter.cbegin(), i_interpreter.cend());
-
-                // Disabling ADL, by directly specifying operators.
-                if(!(out.operator >>(result)))
+                to_target_stream out(src_stream.cbegin(), src_stream.cend());
+                if (!out.stream_out(result))
                     return false;
 
                 return true;
